@@ -1,14 +1,13 @@
 import json
-import boto3
-import typer
 import os
 import subprocess
+import boto3
+import typer
+from github import Github
 
 from devolv.drift.aws_fetcher import get_aws_policy_document, merge_policy_documents, build_superset_policy
 from devolv.drift.issues import create_approval_issue, wait_for_sync_choice
 from devolv.drift.github_approvals import create_github_pr
-from devolv.drift.report import detect_and_print_drift
-from github import Github  # Needed for auto-close
 
 app = typer.Typer()
 
@@ -23,15 +22,32 @@ def push_branch(branch_name: str):
         try:
             subprocess.run(["git", "push", "--set-upstream", "origin", branch_name], check=True)
         except subprocess.CalledProcessError:
-            typer.echo("⚠️ Push failed. Trying to pull + re-push...")
+            typer.echo("⚠️ Initial push failed. Attempting rebase + push...")
             subprocess.run(["git", "pull", "--rebase", "origin", branch_name], check=True)
             subprocess.run(["git", "push", "--set-upstream", "origin", branch_name], check=True)
 
         typer.echo(f"✅ Pushed branch {branch_name} to origin.")
+
     except subprocess.CalledProcessError as e:
         typer.echo(f"❌ Git command failed: {e}")
         raise typer.Exit(1)
 
+def detect_drift(local_doc, aws_doc) -> bool:
+    """Detect if AWS permissions exist that are missing in local (removal drift)."""
+    local_statements = {json.dumps(stmt, sort_keys=True) for stmt in local_doc.get("Statement", [])}
+    aws_statements = {json.dumps(stmt, sort_keys=True) for stmt in aws_doc.get("Statement", [])}
+
+    missing_in_local = aws_statements - local_statements
+
+    if missing_in_local:
+        typer.echo("❌ Drift detected: Your local policy is missing some permissions present in AWS.")
+        for stmt in missing_in_local:
+            typer.echo(stmt)
+        return True
+
+    typer.echo("✅ No drift detected (local may have extra permissions; that's fine).")
+    return False
+
 @app.command()
 def drift(
     policy_name: str = typer.Option(..., "--policy-name", help="Name of the IAM policy"),
@@ -53,25 +69,25 @@ def drift(
         raise typer.Exit(1)
 
     aws_doc = get_aws_policy_document(policy_arn)
-    drift = detect_and_print_drift(local_doc, aws_doc)
 
-    if not drift and not approval_anyway:
-        typer.echo("✅ No drift detected. Use --approval-anyway to force approval.")
+    drift_detected = detect_drift(local_doc, aws_doc)
+
+    if not drift_detected and not approval_anyway:
+        typer.echo("✅ No drift and no forced approval requested.")
         raise typer.Exit()
 
     repo_full_name = repo_full_name or os.getenv("GITHUB_REPOSITORY")
+    token = os.getenv("GITHUB_TOKEN")
+
     if not repo_full_name:
         typer.echo("❌ GitHub repo not specified. Use --repo or set GITHUB_REPOSITORY.")
         raise typer.Exit(1)
-
-    token = os.getenv("GITHUB_TOKEN")
     if not token:
         typer.echo("❌ GITHUB_TOKEN not set in environment.")
         raise typer.Exit(1)
 
     assignees = [a.strip() for a in approvers.split(",") if a.strip()]
     issue_num, _ = create_approval_issue(repo_full_name, token, policy_name, assignees=assignees)
-    typer.echo(f"✅ Created issue #{issue_num} in {repo_full_name}: https://github.com/{repo_full_name}/issues/{issue_num}")
 
     choice = wait_for_sync_choice(repo_full_name, issue_num, token)
     iam = boto3.client("iam")
@@ -109,24 +125,21 @@ def _update_local_and_create_pr(doc, policy_file, repo_full_name, policy_name, i
     with open(policy_file, "w") as f:
         f.write(new_content)
 
-    branch_base = (
+    branch = (
         f"{description.replace(' ', '-').replace('+', 'plus').replace('/', '-')}-policy-{policy_name}"
         .strip("-")
         .lower()
     )
-    branch_name = push_branch(branch_base)
+
+    push_branch(branch)
 
     pr_title = f"Update {policy_file} {description}".strip()
     pr_body = f"This PR updates `{policy_file}` {description}.\n\nLinked to issue #{issue_num}.".strip()
-    pr_num, pr_url = create_github_pr(repo_full_name, branch_name, pr_title, pr_body, issue_num=issue_num)
 
-    typer.echo(f"✅ Created PR #{pr_num}: {pr_url}")
+    pr_num, pr_url = create_github_pr(repo_full_name, branch, pr_title, pr_body, issue_num=issue_num)
 
-    # Close issue *immediately after PR link is posted*
     gh = Github(token)
     repo = gh.get_repo(repo_full_name)
     issue = repo.get_issue(number=issue_num)
     issue.create_comment(f"✅ PR created and linked: {pr_url}. Closing issue.")
     issue.edit(state="closed")
-    typer.echo(f"💬 Commented on and closed issue #{issue_num}")
-
